# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/evaluatr',
                'doc_host': 'https://franckalbinet.github.io',
                'git_url': 'https://github.com/franckalbinet/evaluatr',
                'lib_path': 'evaluatr'},
  'syms': { 'evaluatr.downloaders': { 'evaluatr.downloaders.download_doc': ('downloaders.html#download_doc', 'evaluatr/downloaders.py'),
                                      'evaluatr.downloaders.download_docs': ('downloaders.html#download_docs', 'evaluatr/downloaders.py'),
                                      'evaluatr.downloaders.extract_fname': ('downloaders.html#extract_fname', 'evaluatr/downloaders.py'),
                                      'evaluatr.downloaders.load_evals': ('downloaders.html#load_evals', 'evaluatr/downloaders.py'),
                                      'evaluatr.downloaders.mk_dirs': ('downloaders.html#mk_dirs', 'evaluatr/downloaders.py')},
            'evaluatr.readers': { 'evaluatr.readers.EvalReader': ('readers.html#evalreader', 'evaluatr/readers.py'),
                                  'evaluatr.readers.EvalReader.__call__': ('readers.html#evalreader.__call__', 'evaluatr/readers.py'),
                                  'evaluatr.readers.EvalReader.__init__': ('readers.html#evalreader.__init__', 'evaluatr/readers.py'),
                                  'evaluatr.readers.EvalReader.read': ('readers.html#evalreader.read', 'evaluatr/readers.py'),
                                  'evaluatr.readers.EvalReader.tfm': ('readers.html#evalreader.tfm', 'evaluatr/readers.py'),
                                  'evaluatr.readers.EvalReader.to_json': ('readers.html#evalreader.to_json', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader': ('readers.html#iomreporeader', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader.__init__': ('readers.html#iomreporeader.__init__', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader._mk_docs': ('readers.html#iomreporeader._mk_docs', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader._mk_id': ('readers.html#iomreporeader._mk_id', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader.read': ('readers.html#iomreporeader.read', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader.tfm': ('readers.html#iomreporeader.tfm', 'evaluatr/readers.py'),
                                  'evaluatr.readers.IOMRepoReader.to_json': ('readers.html#iomreporeader.to_json', 'evaluatr/readers.py'),
                                  'evaluatr.readers.iom_input_cfg': ('readers.html#iom_input_cfg', 'evaluatr/readers.py')}}}
